Shape types
===========

.. automodule:: scadpy.d2.shape.types
    :members:
    :exclude-members: Shape

.. autoclass:: scadpy.d2.shape.types.Shape
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:
    :special-members: __eq__, __or__, __and__, __sub__
